#include "definition.h" 
#include "PinMapping.h"
#include "SAB.h"
#include "views.h"
#include "CFGDictionary.h"

SAB sab;

unsigned long currentMs = 0, batteryMs = 0, buttonMs = 0;
int mySize = 3;
View1Packet v1p = {sab.getRtcManager().getDateTime(), sab.getSdCardManager().getSize(GBYTE), sab.getPowerInfo(),0};
ViewAPPacket vap = {sab.getConnectivityManager().softAPmacAddress(), sab.getConnectivityManager().softAPSSID(), sab.getConnectivityManager().softAPIP(), sab.getConnectivityManager().softAPgetStationNum()};
CFGDictionary dico;

void setup() 
{
  // put your setup code here, to run once:
  Serial.println("Starting setup");
  pinMode(GPIO_0, INPUT);
  sab.getScreenManager().addView(&(view_1), &v1p, 0);
  sab.getScreenManager().addView(&(view_2), &vap, 1);
  sab.getScreenManager().addView(&(view_3), NULL, 2);
  sab.getScreenManager().displayView(0);
  if(sab.getRtcManager().hasLostPower())
  {
    Serial.println("Clock lost power");
    sab.getRtcManager().setDateTime(DateTime(F(__DATE__), F(__TIME__)));
  }
  
  Serial.println("End setup");
}

void loop() 
{
  
  if(millis() - currentMs > 1000)
  {
    currentMs = millis();
    v1p.dateTime = sab.getRtcManager().getDateTime();
    v1p.nbViews = sab.getScreenManager().getViewCount();
    vap.ipAddr = sab.getConnectivityManager().softAPIP();
    vap.macAddr = sab.getConnectivityManager().softAPmacAddress();
    vap.nbOfCon = sab.getConnectivityManager().softAPgetStationNum();
    
    sab.getScreenManager().displayView();
    Serial.print(F("View count : "));Serial.println(sab.getScreenManager().getViewCount());
    
    //Dico test
    dico.addParameter("SSID", "ESP8266SwissArmyBoard");
    dico.addParameter("PASSWORD", "APassWord");
    dico.deleteParameter("OTHER");
    Serial.print(F("SSID "));Serial.println(dico("SSID").stringValue());
    Serial.print(F("PASSWORD "));Serial.println(dico("PASSWORD").stringValue());
    Serial.print(F("OTHER "));Serial.println(dico("OTHER").stringValue());
    Serial.print(F("Dico count : "));Serial.println(dico.count());
  }

  if(millis() - batteryMs > 10000)
  {
    batteryMs = millis();
    v1p.powerInfo = sab.getPowerInfo();
    //Dico test
    dico.dispose();
  }
    

  if(digitalRead(GPIO_0) == 0 && millis() - buttonMs > 500)
  {
    buttonMs = millis();
    Serial.println("Changing view");
    Serial.print("Selected view is : ");Serial.println(sab.getScreenManager().getCurrentViewUID());
    
    sab.getScreenManager().displayNextView();
  }
}
